# stor-blockchain
![Alt text](https://www.stor.network/img/stor_logo.svg)

![GitHub contributors](https://img.shields.io/github/contributors/Stor-Network/stor-blockchain?logo=GitHub)

Please check out the [wiki](https://github.com/Stor-Network/stor-blockchain/wiki)
and [FAQ](https://github.com/Stor-Network/stor-blockchain/wiki/FAQ) for
information on this project.

## Installing

This is the GUI for stor-blockchain. It is built into distribution packages in the stor-blockchain repository.

Install instructions are available in the
[INSTALL](https://github.com/Stor-Network/stor-blockchain/wiki/INSTALL)
section of the
[stor-blockchain repository wiki](https://github.com/Stor-Network/stor-blockchain/wiki).

## Running

Once installed, a
[Quick Start Guide](https://github.com/Stor-Network/stor-blockchain/wiki/Quick-Start-Guide)
is available from the repository
[wiki](https://github.com/Stor-Network/stor-blockchain/wiki).
